@@ -7,7 +7,7 @@ use stun::message::*;
 
 use util::Error;
 
-// PriorityAttr represents PRIORITY attribute.
+/// Represents PRIORITY attribute.
 #[derive(Default, PartialEq, Debug, Copy, Clone)]
 pub struct PriorityAttr(pub u32);
 
@@ -16,7 +16,7 @@ const PRIORITY_SIZE: usize = 4; // 32 bit
 impl Setter for PriorityAttr {
     // add_to adds PRIORITY attribute to message.
     fn add_to(&self, m: &mut Message) -> Result<(), Error> {
-        let mut v = vec![0u8; PRIORITY_SIZE];
+        let mut v = vec![0_u8; PRIORITY_SIZE];
         v.copy_from_slice(&self.0.to_be_bytes());
         m.add(ATTR_PRIORITY, &v);
         Ok(())
@@ -24,7 +24,7 @@ impl Setter for PriorityAttr {
 }
 
 impl PriorityAttr {
-    // get_from decodes PRIORITY attribute from message.
+    /// Decodes PRIORITY attribute from message.
     pub fn get_from(&mut self, m: &Message) -> Result<(), Error> {
         let v = m.get(ATTR_PRIORITY)?;
 
